[OpenLayers-Commits] r12297 - sandbox/camptocamp/clientzoom/lib/OpenLayers/Layer

commits-20090109 at openlayers.org commits-20090109 at openlayers.org
Wed Aug 31 05:24:15 EDT 2011


Author: cmoullet
Date: 2011-08-31 02:24:14 -0700 (Wed, 31 Aug 2011)
New Revision: 12297

Modified:
   sandbox/camptocamp/clientzoom/lib/OpenLayers/Layer/Grid.js
Log:
Fix variable name


Modified: sandbox/camptocamp/clientzoom/lib/OpenLayers/Layer/Grid.js
===================================================================
--- sandbox/camptocamp/clientzoom/lib/OpenLayers/Layer/Grid.js	2011-08-31 09:16:24 UTC (rev 12296)
+++ sandbox/camptocamp/clientzoom/lib/OpenLayers/Layer/Grid.js	2011-08-31 09:24:14 UTC (rev 12297)
@@ -276,10 +276,10 @@
                 }
             }
 
-            if (resolution !== availableResolution) {
+            if (resolution !== serverSupportedResolution) {
                 if (forceReTile) {
                     // stretch the layer div
-                    this.transformDiv(availableResolution / resolution);
+                    this.transformDiv(serverSupportedResolution / resolution);
                 }
             } else {
                 // reset the layer width, height, left, top, to deal with
@@ -303,7 +303,7 @@
      * resolution - {Number} The base resolution.
      *
      * Returns:
      * {Number} The closest available resolution.
      */
     getServerSupportedResolution: function(resolution) {
         resolution = resolution || this.map.getResolution();
@@ -330,7 +330,7 @@
      * resolution.
      *
      * Returns:
-     * {Number} The available zoom.
+     * {Number} The closest server supported zoom.
      */
     getServerSupportedZoom: function() {
         return this.map.getZoomForResolution(this.getServerSupportedResolution());
@@ -303,7 +303,7 @@
      *
      * Returns:
-     * {Number} The closest available resolution.
+     * {Number} The closest server supported resolution.
      */
     getServerSupportedResolution: function(resolution) {



More information about the Commits mailing list